summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmphotonsedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmphotonsedit.h')
-rw-r--r--kpovmodeler/pmphotonsedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmphotonsedit.h b/kpovmodeler/pmphotonsedit.h
index c5950eb1..3f6d5971 100644
--- a/kpovmodeler/pmphotonsedit.h
+++ b/kpovmodeler/pmphotonsedit.h
@@ -41,9 +41,9 @@ class PMPhotonsEdit : public PMDialogEditBase
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMPhotonsEdit with tqparent and name
*/
- PMPhotonsEdit( TQWidget* tqparent, const char* name = 0 );
+ PMPhotonsEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -41,9 +41,9 @@ class PMPhotonsEdit : public PMDialogEditBase
public:
/**
- * Creates a PMPhotonsEdit with tqparent and name
+ * Creates a PMPhotonsEdit with parent and name
*/